@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 # shortcuts
 #  os and distros
@@ -11,6 +11,7 @@ use constant os_freebsd  => (os => 'freebsd');
 use constant os_windows  => (os => 'MSWin32');
 use constant os_darwin   => (os => 'darwin'); # really means installer=homebrew
 use constant like_debian => (linuxdistro => '~debian');
+use constant before_debian_stretch => (linuxdistrocodename => [qw(squeeze precise wheezy trusty jessie xenial)]);
 use constant like_fedora => (linuxdistro => '~fedora');
 #  package shortcuts
 use constant freebsd_jpeg => 'jpeg | jpeg-turbo';
@@ -692,7 +693,10 @@ sub mapping {
       [os_freebsd,
        [package => 'firebird25-server']],
       [like_debian,
-       [package => 'firebird-dev']],
+       [before_debian_stretch,
+	[package => 'firebird-dev']],
+       [package => [qw(firebird-dev firebird3.0-server-core)]] # for stretch (and newer?)
+      ],
       [like_fedora,
        [package => 'firebird-devel']],
      ],
@@ -1588,7 +1592,8 @@ sub mapping {
      ],
 
      [cpanmod => 'Kafka::Librd',
-      # no package for freebsd
+      [os_freebsd,
+       [package => 'librdkafka']],
       [like_debian,
        [package => 'librdkafka-dev']]],
 
@@ -1978,6 +1983,15 @@ sub mapping {
        [package => 'liblo-dev']],
      ],
 
+     [cpanmod => 'Net::NATS::Streaming::PB',
+      [os_freebsd,
+       [package => 'protobuf']],
+      [like_debian,
+       [package => 'protobuf-compiler']],
+      [like_fedora,
+       [package => [qw(protobuf-compiler protobuf-devel)]]],
+     ],
+
      [cpanmod => 'Net::NfDump',
       [like_debian,
        [package => ['flex', 'byacc']]],
